==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/ru/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Данные были успешно сохранены',
'L_UPDATE_TITLE'					=> 'Обновление PluXml',
'L_WRONG_PHP_VERSION'				=> 'Для PluXml необходим PHP версии 5 или выше.',

'L_SELECT_LANG'						=> 'Выберите ваш язык',
'L_INPUT_CHANGE'					=> 'Изменить',

'L_UPDATE_UPTODATE'					=> 'Ваша PluXml имеет актуальную версию.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Нет доступных обновлений.',
'L_UPDATE_BACK'						=> 'Вернуться на Главную страницу',
'L_UPDATE_WARNING1'					=> 'Вы собираетесь обновить вашу старую версию PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Пожалуйста, выберите старую версию PluXml, которую вы желаете обновить.',
'L_UPDATE_WARNING2'					=> 'Если вы не можете найти старую версию PluXml в списке ниже, для нее нет автоматического обновления, так как ваша версия очень старая.<br />Мы советуем вам скачать последнюю версию <a href="http://www.pluxml.org">PluXml</a> и проделать новую установку.',
'L_UPDATE_WARNING3'					=> 'Внимание: перед тем, как начать обновление, не забудьте сделать копию вашего сайта, сохранив папку "data" в надежном месте',
'L_UPDATE_START'					=> 'Начать обновление',

'L_UPDATE_ENDED'					=> 'Обновление завершено',
'L_UPDATE_INPROGRESS'				=> 'Происходит обновление',
'L_UPDATE_ERROR'					=> 'Во время обновления произошла ошибка.',
'L_UPDATE_SUCCESSFUL'				=> 'Обновление завершено успешно!',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Обновление parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Создается tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Произошла ошибка во время создания tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Создается файл темы',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Произошла ошибка во время создания файла темы',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Преобразование статей в новый формат',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Произошла ошибка в процессе обработки файла',
'L_UPDATE_STATICS_MIGRATION'		=> 'Миграция файла статических страниц',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Произошла ошибка во время миграции файла статических страниц',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Создается файлы пользователя users\' ',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Произошла ошибка во время создания файла пользователя',
'L_UPDATE_USERS_MIGRATION'			=> 'Миграция файла пользователя users\' ',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Произошла ошибка во время миграции файла пользователя',
'L_UPDATE_ERR_NO_USERS'				=> 'В файле не найдены пользователи',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Создается файл .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Произошла ошибка во время создания файла .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Обновление файла .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Произошла ошибка во время обновления файла .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Миграция файла категорий',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Миграция файла категорий',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Произошла ошибка во время миграции файла категорий',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Создается plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Произошла ошибка во время создания plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Удаление core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Произошла ошибка во время удаления core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Удаление папки core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Произошла ошибка во время удаления папки core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Обновление файла',
'L_UPDATE_ERR_FILE'					=> 'Ошибка при обновлении файла',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Миграция файлов плагина параметров в файле конфигурации',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Обновление plugins.xml',

);
?>

==> pluxml_5.6.orig.tar.gz: PluXml-5.6/core/lang/ru/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Данные были успешно сохранены',
'L_UPDATE_TITLE'					=> 'Обновление PluXml',
'L_WRONG_PHP_VERSION'				=> 'Для PluXml необходим PHP версии 5 или выше.',

'L_SELECT_LANG'						=> 'Выберите ваш язык',
'L_INPUT_CHANGE'					=> 'Изменить',

'L_UPDATE_UPTODATE'					=> 'Ваша PluXml имеет актуальную версию.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Нет доступных обновлений.',
'L_UPDATE_BACK'						=> 'Вернуться на Главную страницу',
'L_UPDATE_WARNING1'					=> 'Вы собираетесь обновить вашу старую версию PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Пожалуйста, выберите старую версию PluXml, которую вы желаете обновить.',
'L_UPDATE_WARNING2'					=> 'Если вы не можете найти старую версию PluXml в списке ниже, для нее нет автоматического обновления, так как ваша версия очень старая.<br />Мы советуем вам скачать последнюю версию <a href="http://www.pluxml.org">PluXml</a> и проделать новую установку.',
'L_UPDATE_WARNING3'					=> 'Внимание: перед тем, как начать обновление, не забудьте сделать копию вашего сайта, сохранив папку "data" в надежном месте',
'L_UPDATE_START'					=> 'Начать обновление',

'L_UPDATE_ENDED'					=> 'Обновление завершено',
'L_UPDATE_INPROGRESS'				=> 'Происходит обновление',
'L_UPDATE_ERROR'					=> 'Во время обновления произошла ошибка.',
'L_UPDATE_SUCCESSFUL'				=> 'Обновление завершено успешно!',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Обновление parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Создается tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Произошла ошибка во время создания tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Создается файл темы',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Произошла ошибка во время создания файла темы',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Преобразование статей в новый формат',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Произошла ошибка в процессе обработки файла',
'L_UPDATE_STATICS_MIGRATION'		=> 'Миграция файла статических страниц',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Произошла ошибка во время миграции файла статических страниц',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Создается файлы пользователя users\' ',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Произошла ошибка во время создания файла пользователя',
'L_UPDATE_USERS_MIGRATION'			=> 'Миграция файла пользователя users\' ',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Произошла ошибка во время миграции файла пользователя',
'L_UPDATE_ERR_NO_USERS'				=> 'В файле не найдены пользователи',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Создается файл .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Произошла ошибка во время создания файла .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Обновление файла .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Произошла ошибка во время обновления файла .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Миграция файла категорий',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Миграция файла категорий',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Произошла ошибка во время миграции файла категорий',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Создается plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Произошла ошибка во время создания plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Удаление core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Произошла ошибка во время удаления core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Удаление папки core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Произошла ошибка во время удаления папки core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Обновление файла',
'L_UPDATE_ERR_FILE'					=> 'Ошибка при обновлении файла',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Миграция файлов плагина параметров в файле конфигурации',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Обновление plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Миграция комментарии',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Ошибка при переходе комментарии',

);
?>
